@@ -27,9 +27,7 @@
 #ifndef HB_TEST_H
 #define HB_TEST_H
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include <hb-config.hh>
 
 #include <hb-glib.h>
 
@@ -37,6 +35,18 @@
 #include <string.h>
 #include <stdio.h>
 
+#ifdef HAVE_STDBOOL_H
+# include <stdbool.h>
+#else
+typedef short bool;
+# ifndef true
+#  define true 1
+# endif
+# ifndef false
+#  define false 0
+# endif
+#endif
+
 HB_BEGIN_DECLS
 
 /* Just in case */
@@ -52,6 +62,17 @@ HB_BEGIN_DECLS
 				  ((const char *) s)[2], \
 				  ((const char *) s)[3]))
 
+#define HB_FACE_ADD_TABLE(face, tag, data) \
+	do { \
+	  hb_blob_t *blob = hb_blob_create_or_fail ((data), \
+						    sizeof (data), \
+						    HB_MEMORY_MODE_READONLY, \
+						    NULL, NULL); \
+	  hb_face_builder_add_table ((face), \
+				     HB_TAG_CHAR4(tag), \
+				     blob); \
+	  hb_blob_destroy (blob); \
+	} while (0)
 
 static inline const char *
 srcdir (void)
@@ -163,6 +184,12 @@ typedef void (*hb_test_fixture_func_t) (void);
 #ifndef g_assert_true
 #define g_assert_true g_assert
 #endif
+#ifndef g_assert_false
+#define g_assert_false(expr) g_assert(!(expr))
+#endif
+#ifndef g_assert_nonnull
+#define g_assert_nonnull  g_assert
+#endif
 #ifndef g_assert_cmpmem
 #define g_assert_cmpmem(m1, l1, m2, l2) g_assert_true (l1 == l2 && memcmp (m1, m2, l1) == 0)
 #endif
@@ -296,9 +323,9 @@ hb_test_open_font_file (const char *font_path)
   char *path = g_strdup (font_path);
 #endif
 
-  hb_blob_t *blob = hb_blob_create_from_file (path);
+  hb_blob_t *blob = hb_blob_create_from_file_or_fail (path);
   hb_face_t *face;
-  if (hb_blob_get_length (blob) == 0)
+  if (!blob)
     g_error ("Font %s not found.", path);
 
   face = hb_face_create (blob, 0);
